from distutils.core import setup

setup(
    name = 'sulley',
    packages = ['sulley'],
version = '0.0.1-alpha',
    description = 'With Sulley, you can build SMS bots in just a few lines of code. Powered by Twilio & Plivo, Sulley requires very minimal configuration and code to bring your bot to life!',
    author = 'Sandeep Raju Prabhakar',
    author_email = 'me@sandeepraju.in',
    url = 'https://github.com/sandeepraju/sulley',
    download_url = 'https://github.com/sandeepraju/sulley/archive/master.zip',
    keywords = ['sms', 'message', 'twilio', 'plivo'],
    classifiers = [
        'Programming Language :: Python',
    ],
)

